/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

#include "Actionpoint.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"

namespace orxonox
{
    RegisterClass(Actionpoint);

    Actionpoint::Actionpoint(Context* context) : StaticEntity(context)
    {
        RegisterObject(Actionpoint);

    }
    
    void Actionpoint::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(Actionpoint, XMLPort, xmlelement, mode);
        
        XMLPortParam( Actionpoint, "action", setActionXML, getActionXML,  xmlelement, mode );
        XMLPortParam( Actionpoint, "protect", setProtectXML, getProtectXML,  xmlelement, mode );
        XMLPortParam( Actionpoint, "attack", setAttackXML, getAttackXML,  xmlelement, mode );
        XMLPortParam( Actionpoint, "protectMe", setProtectMeXML, getProtectMeXML,  xmlelement, mode ).defaultValues(false);
        XMLPortParam( Actionpoint, "loopStart", setLoopStart, getLoopStart,  xmlelement, mode ).defaultValues(false);
        XMLPortParam( Actionpoint, "loopEnd", setLoopEnd, getLoopEnd,  xmlelement, mode ).defaultValues(false);

    }
    void Actionpoint::setActionXML( std::string val)
    {
        this->actionName_ = getUppercase( val );
        orxout(internal_error) << "action = " << this->actionName_ << endl;
    }

    std::string Actionpoint::getActionXML()
    {
        return this->actionName_;
    }
    void Actionpoint::setProtectXML( std::string val)
    {
        this->protectName_ = val;
    }

    std::string Actionpoint::getProtectXML()
    {
        return this->protectName_;
    }
    void Actionpoint::setAttackXML( std::string val)
    {
        this->attackName_ = val;
    }

    std::string Actionpoint::getAttackXML()
    {
        return this->attackName_;
    }
   
    void Actionpoint::setTargetPosition(const Vector3& target)
    {
        this->targetPosition_ = target;
    }
    Vector3 Actionpoint::getTargetPosition ()
    {
        return this->targetPosition_;
    }
    
}
